@@ -20,16 +20,16 @@ def print_tr(data: dict, offset: Optional[int]=1) -> None:
                 print(f"{' '*offset*4}{key}: None")
             elif type(val) is list:
                 print(f"{' '*offset*4}{key}: (List)")
-                triverse_dict(val, offset+1)
+                print_tr(val, offset+1)
             elif type(val) is dict:
                 print(f"{' '*offset*4}{key}: (Dict)")
-                triverse_dict(val, offset+1)
+                print_tr(val, offset+1)
             else:
                 print(f"{' '*offset*4}{key}: {val}")
 
     elif type(data) is list:
         for ele in data:
-            triverse_dict(ele, offset)
+            print_tr(ele, offset)
 
     else:
         print(f"{'    '*offset}- {data}")
